@@ -1,11 +1,12 @@
 #![feature(test)]
 extern crate test;
 extern crate jsonwebtoken as jwt;
-extern crate rustc_serialize;
+#[macro_use]
+extern crate serde_derive;
 
-use jwt::{encode, decode, Algorithm, Header};
+use jwt::{encode, decode, Header, Validation};
 
-#[derive(Debug, PartialEq, Clone, RustcEncodable, RustcDecodable)]
+#[derive(Debug, PartialEq, Clone, Serialize, Deserialize)]
 struct Claims {
     sub: String,
     company: String
@@ -18,11 +19,11 @@ fn bench_encode(b: &mut test::Bencher) {
         company: "ACME".to_owned()
     };
 
-    b.iter(|| encode(Header::default(), &claim, "secret".as_ref()));
+    b.iter(|| encode(&Header::default(), &claim, "secret".as_ref()));
 }
 
 #[bench]
 fn bench_decode(b: &mut test::Bencher) {
     let token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwibmFtZSI6IkpvaG4gRG9lIiwiYWRtaW4iOnRydWV9.TJVA95OrM7E2cBab30RMHrHDcEfxjoYZgeFONFh7HgQ";
-    b.iter(|| decode::<Claims>(token, "secret".as_ref(), Algorithm::HS256));
+    b.iter(|| decode::<Claims>(token, "secret".as_ref(), &Validation::default()));
 }
